@@ -1,11 +1,11 @@
-# $Id: TCP.pm,v 1.42 2004/07/15 14:01:38 rcaputo Exp $
+# $Id: TCP.pm 1922 2006-04-04 04:19:10Z rcaputo $
 
 package POE::Component::Client::TCP;
 
 use strict;
 
 use vars qw($VERSION);
-$VERSION = do {my@r=(q$Revision: 1.42 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
+$VERSION = do {my($r)=(q$Revision: 1922 $=~/(\d+)/);sprintf"1.%04d",$r};
 
 use Carp qw(carp croak);
 use Errno qw(ETIMEDOUT ECONNRESET);
@@ -95,6 +95,10 @@ sub new {
 
   croak "$mi requires a ServerInput parameter" unless defined $input_callback;
 
+  foreach (sort keys %param) {
+    carp "$mi doesn't recognize \"$_\" as a parameter";
+  }
+
   # Defaults.
 
   $session_type = 'POE::Session' unless defined $session_type;
@@ -106,14 +110,19 @@ sub new {
     $session_params = [ ];
   }
 
-  my @filter_args;
   $address = '127.0.0.1' unless defined $address;
-  unless (defined $filter) {
-    $filter = "POE::Filter::Line";
-  }
-  elsif (ref($filter) eq 'ARRAY') {
+
+  my @filter_args;
+  if (ref $filter eq 'ARRAY') {
     @filter_args = @$filter;
-    $filter      = shift @filter_args;
+    $filter = shift @filter_args;
+    $filter = $filter->new(@filter_args);
+  } elsif (ref $filter) {
+    $filter = $filter->clone();
+  } elsif (!defined($filter)) {
+    $filter = POE::Filter::Line->new();
+  } else {
+    $filter = $filter->new();
   }
 
   $conn_error_callback = \&_default_error unless defined $conn_error_callback;
@@ -187,7 +196,7 @@ sub new {
           $_[HEAP]->{server} = POE::Wheel::ReadWrite->new
             ( Handle       => $socket,
               Driver       => POE::Driver::SysRW->new(),
-              Filter       => $filter->new(@filter_args),
+              Filter       => $filter,
               InputEvent   => 'got_server_input',
               ErrorEvent   => 'got_server_error',
               FlushedEvent => 'got_server_flush',
