@@ -6,7 +6,7 @@ testreport.pl - generate a test report in xml
 
 =head1 VERSION
 
-$Revision: 1.12 $
+$Revision: 1903 $
 
 =head1 USAGE
 
@@ -21,16 +21,19 @@ This program was written by Matt Cashner.
 =cut
 
 package My::Strap;
-use lib qw(../mylib ../ ./mylib ./);
+use lib qw(../mylib ../ ./mylib ./ ../lib ./lib);
 use Test::Harness;
 use base qw(Test::Harness::Straps);
 use Sys::Hostname;
 use vars qw($VERSION);
 
-$VERSION = (qw($Revision: 1.12 $))[1];
+$VERSION = do {my($r)=(q$Revision: 1903 $=~/(\d+)/);sprintf"1.%04d",$r};
 
 local $| = 1;
 
+# Makefile.PL does it.  Why don't we?
+$ENV{PERL_DL_NONLAZY} = 1;
+
 my $s = My::Strap->new;
 
 my %handlers = (
@@ -83,8 +86,7 @@ sub _print {
 # Locate Makefile.  This allows the script to be run from POE's main
 # directory or from lib itself.
 
-my @test_files;
-my $directory = "";
+my $directory = ".";
 
 unless (-e "Makefile") {
   unless (-e "../Makefile") {
@@ -93,20 +95,28 @@ unless (-e "Makefile") {
   $directory = "../";
 }
 
-# Fetch from Makefile the tests POE has been configured with.  Prepend
-# $directory to each so they're found no matter where the report is
-# run.
+# Find the test files beneath the Makefile directory.
 
-open(MAKEFILE, "${directory}Makefile")
-  or die "Cannot read ${directory}Makefile: $!";
+use File::Find;
+use File::Spec;
 
-while (<MAKEFILE>) {
-  chomp;
-  next unless /^TEST_FILES\s*=\s*(.*?)\s*$/;
-  @test_files = map { $directory . $_ } split /\s+/, $1;
-  last;
-}
-close MAKEFILE;
+my %test_files;
+find(
+  sub {
+    return unless -f;
+    return unless /\.t$/;
+    $test_files{File::Spec->catfile($File::Find::dir, $_)} = 1;
+  },
+  $directory,
+);
+
+my @test_files = sort keys %test_files;
+
+# Require POE early, so we don't bother with the tests if something
+# catastrophic has occurred (like POE's library directory moves
+# outside C<use lib> or something).  The version number is still
+# dumped into the XML file at the appropriate time.
+require POE;
 
 my %test_results;
 my $width = Test::Harness::_leader_width(@test_files);
@@ -114,8 +124,8 @@ foreach my $file (@test_files) {
     ($leader, $ml) = Test::Harness::_mk_leader($file, $width);
     print $leader;
     my %result = $s->analyze_file($file);
-    $file =~ s#^\.\./t/##;
-    $file =~ s#^t/##;
+    $file =~ s#^\.\.?/##;
+    $file =~ s#^tests/##;
     $test_results{$file} = \%result;
     $s->_display($result{passing} ? 'ok' : 'FAILED');
     print "\n";
@@ -173,13 +183,10 @@ eval {
 $xml .= "\t<perl_modules>\n";
 $xml .= "\t\t<perl version=\"$]\" />\n";
 
-eval "require POE;";
-if($@) {
-    $xml .= "\t\t<poe />\n";
-} else {
-    $xml .= "\t\t<poe version=\"$POE::VERSION\" />\n";
-}
-    
+# Dump POE's version.  POE has been required earlier, without an
+# eval() wrapper, so the version must be available by this time.
+$xml .= "\t\t<poe version=\"$POE::VERSION\" />\n";
+
 eval "use Gtk;";
 if($@) {
     $xml .= "\t\t<gtk />\n";
